@@ -24,11 +24,24 @@ test_that("bcdata.chunk_limit",{
 })
 
 test_that("bcdata.single_download_limit", {
+  skip_on_cran()
   withr::local_options(list(bcdata.single_download_limit = 1))
   expect_message(
     bcdc_get_data(record = '76b1b7a3-2112-4444-857a-afccf7b20da8', resource =
                     '4d0377d9-e8a1-429b-824f-0ce8f363512c'),
-    "pagination"
+    "paginated"
   )
 
 })
+
+test_that("bcdata.single_download_limit can be changed",{
+  withr::local_options(list(bcdata.single_download_limit = 13))
+  expect_equal(getOption("bcdata.single_download_limit"), 13)
+})
+
+test_that("bcdc_single_download_limit returns a number",{
+  skip_on_cran()
+  skip_if_net_down()
+  lt <- bcdc_single_download_limit()
+  expect_type(lt, "integer")
+})
